@@ -1,7 +1,5 @@
 package CHI::Driver::DBI::t::CHIDriverTests::Base;
-{
-  $CHI::Driver::DBI::t::CHIDriverTests::Base::VERSION = '1.26';
-}
+$CHI::Driver::DBI::t::CHIDriverTests::Base::VERSION = '1.27';
 use DBI;
 use Module::Load::Conditional qw(can_load);
 use Test::More;
@@ -70,4 +68,6 @@ sub test_with_dbi_generator : Tests(1) {
     is( $cache->get('foo'), $t );
 }
 
+sub test_multiple_processes { }
+
 1;
